==> binnie-mods-1.11.2-2.1.0.33-sources.jar: binnie/core/machines/TileEntityMachine.java <==
package binnie.core.machines;

import javax.annotation.Nullable;

import net.minecraft.block.state.IBlockState;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.network.NetworkManager;
import net.minecraft.network.play.server.SPacketUpdateTileEntity;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.World;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import binnie.Binnie;
import binnie.core.machines.base.TileEntityMachineBase;
import binnie.core.machines.component.IInteraction;
import binnie.core.network.INetworkedEntity;
import binnie.core.network.packet.PacketPayload;

public class TileEntityMachine extends TileEntityMachineBase implements INetworkedEntity {
	private Machine machine;

	public TileEntityMachine(final MachinePackage pack) {
		this.setMachine(pack);
	}

	public TileEntityMachine() {
	}

	@Override
	public void func_73660_a() {
		super.func_73660_a();
		if (this.machine != null) {
			this.machine.onUpdate();
		}
	}

	@Override
	public void func_145839_a(final NBTTagCompound nbtTagCompound) {
		super.func_145839_a(nbtTagCompound);
		if(!nbtTagCompound.func_74764_b("sync")) {
			final String name = nbtTagCompound.func_74779_i("name");
			final String group = nbtTagCompound.func_74779_i("group");
			final MachinePackage pack = Binnie.MACHINE.getPackage(group, name);
			if (pack == null) {
				this.func_145843_s();
				return;
			}
			this.setMachine(pack);
			this.getMachine().readFromNBT(nbtTagCompound);
		}
	}

	@Override
	public NBTTagCompound func_189515_b(final NBTTagCompound nbtTagCompound2) {
		NBTTagCompound nbtTagCompound = super.func_189515_b(nbtTagCompound2);
		final String name = this.machine.getPackage().getUID();
		final String group = this.machine.getPackage().getGroup().getUID();
		nbtTagCompound.func_74778_a("group", group);
		nbtTagCompound.func_74778_a("name", name);
		this.getMachine().writeToNBT(nbtTagCompound);
		return nbtTagCompound;
	}

	@Override
	public void writeToPacket(final PacketPayload payload) {
		this.machine.writeToPacket(payload);
	}

	@Override
	public void readFromPacket(final PacketPayload payload) {
		this.machine.readFromPacket(payload);
	}

	@Override
	public boolean shouldRefresh(World world, BlockPos pos, IBlockState oldState, IBlockState newSate) {
		return super.shouldRefresh(world, pos, oldState, newSate);
	}

	@Nullable
	@Override
	public SPacketUpdateTileEntity func_189518_D_() {
		return new SPacketUpdateTileEntity(this.func_174877_v(), 0, func_189517_E_());
	}

	@Override
	@SideOnly(Side.CLIENT)
	public void onDataPacket(NetworkManager net, SPacketUpdateTileEntity pkt) {
		super.onDataPacket(net, pkt);
		NBTTagCompound nbt = pkt.func_148857_g();
		handleUpdateTag(nbt);
	}

	@Override
	public NBTTagCompound func_189517_E_() {
		NBTTagCompound compound = super.func_189517_E_();
		NBTTagCompound syncCompound = new NBTTagCompound();
		machine.syncToNBT(syncCompound);
		compound.func_74782_a("sync", syncCompound);
		return compound;
	}

	@Override
	public void handleUpdateTag(NBTTagCompound tag) {
		super.handleUpdateTag(tag);
		NBTTagCompound syncCompound = tag.func_74775_l("sync");
		machine.syncFromNBT(syncCompound);
	}

	public Machine getMachine() {
		return this.machine;
	}

	public void setMachine(final MachinePackage pack) {
		if (pack != null) {
			this.machine = new Machine(pack, this);
		}
	}

	public void onBlockDestroy() {
		if (this.getMachine() != null) {
			this.getMachine().onBlockDestroy();
		}
	}

	@Override
	public void func_145843_s() {
		super.func_145843_s();
		for (final IInteraction.Invalidation c : this.getMachine().getInterfaces(IInteraction.Invalidation.class)) {
			c.onInvalidation();
		}
	}

	@Override
	public void onChunkUnload() {
		super.onChunkUnload();
		for (final IInteraction.ChunkUnload c : this.getMachine().getInterfaces(IInteraction.ChunkUnload.class)) {
			c.onChunkUnload();
		}
	}
}

==> binnie-mods-1.11.2-2.1.0.40-sources.jar: binnie/core/machines/TileEntityMachine.java <==
package binnie.core.machines;

import javax.annotation.Nullable;

import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.network.NetworkManager;
import net.minecraft.network.play.server.SPacketUpdateTileEntity;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import binnie.Binnie;
import binnie.core.machines.base.TileEntityMachineBase;
import binnie.core.machines.component.IInteraction;
import binnie.core.network.INetworkedEntity;
import binnie.core.network.packet.PacketPayload;

public class TileEntityMachine extends TileEntityMachineBase implements INetworkedEntity {
	private Machine machine;

	public TileEntityMachine(final MachinePackage pack) {
		this.setMachine(pack);
	}

	public TileEntityMachine() {
	}

	@Override
	public void func_73660_a() {
		super.func_73660_a();
		if (this.machine != null) {
			this.machine.onUpdate();
		}
	}

	@Override
	public void func_145839_a(final NBTTagCompound nbtTagCompound) {
		super.func_145839_a(nbtTagCompound);
		if(!nbtTagCompound.func_74764_b("sync")) {
			final String name = nbtTagCompound.func_74779_i("name");
			final String group = nbtTagCompound.func_74779_i("group");
			final MachinePackage pack = Binnie.MACHINE.getPackage(group, name);
			if (pack == null) {
				this.func_145843_s();
				return;
			}
			this.setMachine(pack);
			this.getMachine().readFromNBT(nbtTagCompound);
		}
	}

	@Override
	public NBTTagCompound func_189515_b(final NBTTagCompound nbtTagCompound2) {
		NBTTagCompound nbtTagCompound = super.func_189515_b(nbtTagCompound2);
		final String name = this.machine.getPackage().getUID();
		final String group = this.machine.getPackage().getGroup().getUID();
		nbtTagCompound.func_74778_a("group", group);
		nbtTagCompound.func_74778_a("name", name);
		this.getMachine().writeToNBT(nbtTagCompound);
		return nbtTagCompound;
	}

	@Override
	public void writeToPacket(final PacketPayload payload) {
		this.machine.writeToPacket(payload);
	}

	@Override
	public void readFromPacket(final PacketPayload payload) {
		this.machine.readFromPacket(payload);
	}

	@Nullable
	@Override
	public SPacketUpdateTileEntity func_189518_D_() {
		return new SPacketUpdateTileEntity(this.func_174877_v(), 0, func_189517_E_());
	}

	@Override
	@SideOnly(Side.CLIENT)
	public void onDataPacket(NetworkManager net, SPacketUpdateTileEntity pkt) {
		super.onDataPacket(net, pkt);
		NBTTagCompound nbt = pkt.func_148857_g();
		handleUpdateTag(nbt);
	}

	@Override
	public NBTTagCompound func_189517_E_() {
		NBTTagCompound compound = super.func_189517_E_();
		NBTTagCompound syncCompound = new NBTTagCompound();
		machine.syncToNBT(syncCompound);
		compound.func_74782_a("sync", syncCompound);
		return compound;
	}

	@Override
	public void handleUpdateTag(NBTTagCompound tag) {
		super.handleUpdateTag(tag);
		NBTTagCompound syncCompound = tag.func_74775_l("sync");
		machine.syncFromNBT(syncCompound);
	}

	public Machine getMachine() {
		return this.machine;
	}

	public void setMachine(MachinePackage pack) {
		if (pack != null) {
			this.machine = new Machine(pack, this);
		}
	}

	public void onBlockDestroy() {
		if (this.getMachine() != null) {
			this.getMachine().onBlockDestroy();
		}
	}

	@Override
	public void func_145843_s() {
		super.func_145843_s();
		for (IInteraction.Invalidation c : this.getMachine().getInterfaces(IInteraction.Invalidation.class)) {
			c.onInvalidation();
		}
	}

	@Override
	public void onChunkUnload() {
		super.onChunkUnload();
		for (IInteraction.ChunkUnload c : this.getMachine().getInterfaces(IInteraction.ChunkUnload.class)) {
			c.onChunkUnload();
		}
	}
}
